# Generated by roxygen2: do not edit by hand

S3method(print,easystat_result)
S3method(summary,easystat_result)
export(easy_anova)
export(easy_autoplot)
export(easy_barplot)
export(easy_boxplot)
export(easy_chisq)
export(easy_correlation)
export(easy_correlation_heatmap)
export(easy_density)
export(easy_describe)
export(easy_ftest)
export(easy_group_summary)
export(easy_histogram)
export(easy_kruskal)
export(easy_logistic_regression)
export(easy_odds_ratio_plot)
export(easy_qqplot)
export(easy_regression)
export(easy_regression_diagnostics)
export(easy_scatter)
export(easy_ttest)
export(easy_wilcox)
export(easy_ztest)
export(export_to_word)
export(theme_easystat)
