% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_odds_ratio_plot}
\alias{easy_odds_ratio_plot}
\title{Odds Ratio Plot for Logistic Regression}
\usage{
easy_odds_ratio_plot(result)
}
\arguments{
\item{result}{An \code{"easystat_result"} from \code{easy_logistic_regression()}.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Creates a coefficient figure showing odds ratios and confidence intervals
for \code{\link{easy_logistic_regression}} results.
}
