% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_regression_diagnostics}
\alias{easy_regression_diagnostics}
\title{Regression Diagnostic Plot}
\usage{
easy_regression_diagnostics(result)
}
\arguments{
\item{result}{An \code{"easystat_result"} from \code{easy_regression()}.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Creates a fitted-vs-residuals diagnostic figure for linear regression
results returned by \code{\link{easy_regression}}.
}
